;;;; -*- Mode: Lisp; Syntax: ANSI-Common-Lisp; Base: 10 -*-
;;;; *************************************************************************
;;;; FILE IDENTIFICATION
;;;;
;;;; Name:          kmrcl-tests.lisp
;;;; Purpose:       kmrcl tests file
;;;; Author:        Kevin M. Rosenberg
;;;; Date Started:  Apr 2003
;;;;
;;;; $Id: tests.lisp,v 1.6 2003/05/04 14:52:10 kevin Exp $
;;;;
;;;; This file is Copyright (c) 2000-2002 by Kevin M. Rosenberg
;;;;
;;;; *************************************************************************

(defpackage #:kmrcl-tests
  (:use #:kmrcl #:cl #:rtest))
(in-package #:kmrcl-tests)

(rem-all-tests)



(deftest str.0 (substitute-chars-strings "" nil) "")
(deftest str.1 (substitute-chars-strings "abcd" nil) "abcd")
(deftest str.2 (substitute-chars-strings "abcd" nil) "abcd")
(deftest str.3 (substitute-chars-strings "abcd" '((#\j . "ef"))) "abcd")
(deftest str.4 (substitute-chars-strings "abcd" '((#\a . "ef"))) "efbcd")
(deftest str.5
    (substitute-chars-strings "abcd" '((#\a . "ef") (#\j . "ghi")))
  "efbcd")
(deftest str.6
    (substitute-chars-strings "abcd" '((#\a . "ef") (#\d . "ghi")))
  "efbcghi")

(deftest str.7 (escape-xml-string "") "")
(deftest str.8 (escape-xml-string "abcd") "abcd")
(deftest str.9 (escape-xml-string "ab&cd") "ab&amp;cd")
(deftest str.10 (escape-xml-string "ab&cd<") "ab&amp;cd&lt;")
(deftest str.11 (escape-xml-string "ab&c><") "ab&amp;c&gt;&lt;")
(deftest str.12 (string-trim-last-character "") "")
(deftest str.13 (string-trim-last-character "a") "")
(deftest str.14 (string-trim-last-character "ab") "a")
(deftest str.15 (nstring-trim-last-character "") "")
(deftest str.16 (nstring-trim-last-character "a") "")
(deftest str.17 (nstring-trim-last-character "ab") "a")

(deftest str.18 (delimited-string-to-list "ab|cd|ef") '("ab" "cd" "ef"))
(deftest str.19 (ndelimited-string-to-list "ab|cd|ef") '("ab" "cd" "ef"))
(deftest str.20 (delimited-string-to-list "") nil)
(deftest str.21 (ndelimited-string-to-list "") nil)
(deftest str.22 (delimited-string-to-list "ab") '("ab"))
(deftest str.23 (ndelimited-string-to-list "ab") '("ab"))
(deftest str.24 (delimited-string-to-list "ab|") '("ab" ""))
(deftest str.25 (ndelimited-string-to-list "ab|") '("ab" ""))
  
(eval-when (:compile-toplevel :load-toplevel :execute)
  (when (find-package '#:kmr-mop)
    (pushnew :kmrtest-mop cl:*features*)))

#+kmrtest-mop
(progn
  (defclass credit-rating ()
    ((level :attributes (date-set time-set))
     (id :attributes (person-setting)))
    (:metaclass attributes-class))
  (defparameter cr nil)
  
  (defclass monitored-credit-rating (credit-rating)
    ((level :attributes (last-checked interval date-set))
     (cc :initarg :cc)
     (id :attributes (verified)))
    (:metaclass attributes-class))
  (defparameter mcr (make-instance 'monitored-credit-rating))

  (deftest attrib.mop.1
      (progn
	(setq cr (make-instance 'credit-rating))
	(slot-attribute cr 'level 'date-set))
      nil)

  (deftest attrib.mop.2
      (progn
	(setq cr (make-instance 'credit-rating))
	(setf (slot-attribute cr 'level 'date-set) "12/15/1990")
	(slot-attribute cr 'level 'date-set))
    "12/15/1990")

  (deftest attrib.mop.3
      (progn
	(setq mcr (make-instance 'monitored-credit-rating))
	(setf (slot-attribute mcr 'level 'date-set) "01/05/2002")
	(slot-attribute mcr 'level 'date-set))
    "01/05/2002")
  
  )   ;; kmrcl-mop

#+kmrtest-mop
(eval-when (:compile-toplevel :load-toplevel :execute)
  (setq cl:*features* (delete :kmrtest-mop cl:*features*)))
